@@ -80,6 +80,7 @@ var npm = require("./npm.js")
   , inflight = require("inflight")
   , npa = require("npm-package-arg")
   , getStat = require("./cache/get-stat.js")
+  , cachedPackageRoot = require("./cache/cached-package-root.js")
 
 cache.usage = "npm cache add <tarball file>"
             + "\nnpm cache add <folder>"
@@ -130,7 +131,7 @@ function read (name, ver, forceBypass, cb) {
 
   if (forceBypass === undefined || forceBypass === null) forceBypass = true
 
-  var jsonFile = path.join(npm.cache, name, ver, "package", "package.json")
+  var root = cachedPackageRoot({name : name, version : ver})
   function c (er, data) {
     if (data) deprCheck(data)
 
@@ -142,7 +143,7 @@ function read (name, ver, forceBypass, cb) {
     return addNamed(name, ver, null, c)
   }
 
-  readJson(jsonFile, function (er, data) {
+  readJson(path.join(root, "package", "package.json"), function (er, data) {
     er = needName(er, data)
     er = needVersion(er, data)
     if (er && er.code !== "ENOENT" && er.code !== "ENOTDIR") return cb(er)
@@ -224,7 +225,6 @@ cache.add = function (pkg, ver, where, scrub, cb) {
       add([pkg, ver], where, cb)
     })
   }
-  log.verbose("cache add", [pkg, ver])
   return add([pkg, ver], where, cb)
 }
 
@@ -249,6 +249,8 @@ function add (args, where, cb) {
     , spec
     , p
 
+  log.silly("cache add", "args", args)
+
   if (args[1] === undefined) args[1] = null
 
   // at this point the args length must ==2
@@ -258,7 +260,7 @@ function add (args, where, cb) {
     spec = args[0]
   }
 
-  log.verbose("cache add", "spec=%j args=%j", spec, args)
+  log.verbose("cache add", "spec", spec)
 
   if (!spec) return cb(usage)
 
@@ -272,7 +274,7 @@ function add (args, where, cb) {
   // normalization
   p = npa(spec)
   if (p.type === "local" && where) spec = path.resolve(where, p.spec)
-  log.verbose("parsed spec", p)
+  log.silly("cache add", "parsed spec", p)
 
   // short-circuit local installs
   fs.stat(spec, function (er, s) {
@@ -292,7 +294,7 @@ function addAndLogLocal (spec, cb) {
 
 function addNonLocal (spec, cb) {
     var p = npa(spec)
-    log.verbose("parsed spec", p)
+    log.silly("addNonLocal", "parsed spec", p)
 
     switch (p.type) {
       case "remote":
@@ -324,7 +326,7 @@ function unpack (pkg, ver, unpackTarget, dMode, fMode, uid, gid, cb) {
     }
     npm.commands.unbuild([unpackTarget], true, function (er) {
       if (er) return cb(er)
-      tar.unpack( path.join(npm.cache, pkg, ver, "package.tgz")
+      tar.unpack( path.join(cachedPackageRoot({name : pkg, version : ver}), "package.tgz")
                 , unpackTarget
                 , dMode, fMode
                 , uid, gid
@@ -344,9 +346,7 @@ function afterAdd (cb) { return function (er, data) {
 
   // Save the resolved, shasum, etc. into the data so that the next
   // time we load from this cached data, we have all the same info.
-  var name = data.name
-  var ver = data.version
-  var pj = path.join(npm.cache, name, ver, "package", "package.json")
+  var pj = path.join(cachedPackageRoot(data), "package", "package.json")
 
   var done = inflight(pj, cb)
 
