@@ -10,10 +10,8 @@ var path = require("path")
   , registry = npm.registry
   , deprCheck = require("../utils/depr-check.js")
   , inflight = require("inflight")
-  , locker = require("../utils/locker.js")
-  , lock = locker.lock
-  , unlock = locker.unlock
   , addRemoteTarball = require("./add-remote-tarball.js")
+  , cachedPackageRoot = require("./cached-package-root.js")
   , mapToRegistry = require("../utils/map-to-registry.js")
 
 
@@ -24,28 +22,25 @@ function addNamed (name, version, data, cb_) {
   assert(typeof name === "string", "must have module name")
   assert(typeof cb_ === "function", "must have callback")
 
-  log.verbose("addNamed", [name, version])
-
   var key = name + "@" + version
+  log.verbose("addNamed", key)
+
   function cb (er, data) {
     if (data && !data._fromGithub) data._from = key
-    unlock(key, function () { cb_(er, data) })
+    cb_(er, data)
   }
 
   cb_ = inflight(NAME_PREFIX + key, cb_)
 
   if (!cb_) return
 
-  log.verbose("addNamed", [semver.valid(version), semver.validRange(version)])
-  lock(key, function (er) {
-    if (er) return cb(er)
-
-    var fn = ( semver.valid(version, true) ? addNameVersion
-             : semver.validRange(version, true) ? addNameRange
-             : addNameTag
-             )
-    fn(name, version, data, cb)
-  })
+  log.silly("addNamed", "semver.valid", semver.valid(version))
+  log.silly("addNamed", "semver.validRange", semver.validRange(version))
+  var fn = ( semver.valid(version, true) ? addNameVersion
+           : semver.validRange(version, true) ? addNameRange
+           : addNameTag
+           )
+  fn(name, version, data, cb)
 }
 
 function addNameTag (name, tag, data, cb) {
@@ -147,7 +142,7 @@ function addNameVersion (name, v, data, cb) {
     }
 
     // we got cached data, so let's see if we have a tarball.
-    var pkgroot = path.join(npm.cache, name, ver)
+    var pkgroot = cachedPackageRoot({name : name, version : ver})
     var pkgtgz = path.join(pkgroot, "package.tgz")
     var pkgjson = path.join(pkgroot, "package", "package.json")
     fs.stat(pkgtgz, function (er) {
@@ -158,6 +153,10 @@ function addNameVersion (name, v, data, cb) {
           if (er && er.code !== "ENOENT" && er.code !== "ENOTDIR")
             return cb(er)
           if (er) return fetchit()
+          // check the SHA of the package we have, to ensure it wasn't installed
+          // from somewhere other than the registry (eg, a fork)
+          if (data._shasum && dist.shasum && data._shasum !== dist.shasum)
+            return fetchit()
           return cb(null, data)
         })
       } else return fetchit()
