@@ -12,12 +12,9 @@ var mkdir = require("mkdirp")
   , npm = require("../npm.js")
   , rm = require("../utils/gently-rm.js")
   , inflight = require("inflight")
-  , locker = require("../utils/locker.js")
-  , lock = locker.lock
-  , unlock = locker.unlock
   , getCacheStat = require("./get-stat.js")
   , addLocalTarball = require("./add-local-tarball.js")
-  , writeStream = require('fs-write-stream-atomic')
+  , writeStream = require("fs-write-stream-atomic")
 
 
 // 1. cacheDir = path.join(cache,'_git-remotes',sha1(u))
@@ -27,17 +24,13 @@ var mkdir = require("mkdirp")
 // 5. git archive /tmp/random.tgz
 // 6. addLocalTarball(/tmp/random.tgz) <gitref> --format=tar --prefix=package/
 // silent flag is used if this should error quietly
-module.exports = function addRemoteGit (u, silent, cb_) {
+module.exports = function addRemoteGit (u, silent, cb) {
   assert(typeof u === "string", "must have git URL")
-  assert(typeof cb_ === "function", "must have callback")
+  assert(typeof cb === "function", "must have callback")
 
-  function cb (er, data) {
-    unlock(u, function () { cb_(er, data) })
-  }
+  cb = inflight(u, cb)
 
-  cb_ = inflight(u, cb_)
-
-  if (!cb_) return
+  if (!cb) return
 
   log.verbose("addRemoteGit", "u=%j silent=%j", u, silent)
   var parsed = url.parse(u, true)
@@ -57,23 +50,24 @@ module.exports = function addRemoteGit (u, silent, cb_) {
     u = u.replace(/^ssh:\/\//, "")
   }
 
-  lock(u, function (er) {
+  // figure out what we should check out.
+  var co = parsed.hash && parsed.hash.substr(1) || "master"
+
+  var v = crypto.createHash("sha1").update(u).digest("hex").slice(0, 8)
+  v = u.replace(/[^a-zA-Z0-9]+/g, "-")+"-"+v
+
+  log.verbose("addRemoteGit", [u, co])
+
+  var p = path.join(npm.config.get("cache"), "_git-remotes", v)
+
+  // we don't need global templates when cloning.  use this empty dir to specify as template dir
+  mkdir(path.join(npm.config.get("cache"), "_git-remotes", "_templates"), function (er) {
     if (er) return cb(er)
+    checkGitDir(p, u, co, origUrl, silent, function (er, data) {
+      if (er) return cb(er, data)
 
-    // figure out what we should check out.
-    var co = parsed.hash && parsed.hash.substr(1) || "master"
-
-    var v = crypto.createHash("sha1").update(u).digest("hex").slice(0, 8)
-    v = u.replace(/[^a-zA-Z0-9]+/g, "-")+"-"+v
-
-    log.verbose("addRemoteGit", [u, co])
-
-    var p = path.join(npm.config.get("cache"), "_git-remotes", v)
-
-    checkGitDir(p, u, co, origUrl, silent, function(er, data) {
-      addModeRecursive(p, npm.modes.file, function(erAddMode) {
-        if (er) return cb(er, data)
-        return cb(erAddMode, data)
+      addModeRecursive(p, npm.modes.file, function (er) {
+        return cb(er, data)
       })
     })
   })
@@ -111,7 +105,8 @@ function cloneGitRemote (p, u, co, origUrl, silent, cb) {
   mkdir(p, function (er) {
     if (er) return cb(er)
 
-    var args = [ "clone", "--mirror", u, p ]
+    var args = [ "clone", "--template=" + path.join(npm.config.get("cache"),
+      "_git_remotes", "_templates"), "--mirror", u, p ]
     var env = gitEnv()
 
     // check for git
@@ -276,4 +271,3 @@ function dirMode(mode) {
   if (mode & parseInt(  "04", 8)) mode |= parseInt(  "01", 8)
   return mode
 }
-
