@@ -4,13 +4,10 @@ var mkdir = require("mkdirp")
   , path = require("path")
   , sha = require("sha")
   , retry = require("retry")
-  , createWriteStream = require("graceful-fs").createWriteStream
+  , createWriteStream = require("fs-write-stream-atomic")
   , npm = require("../npm.js")
   , registry = npm.registry
   , inflight = require("inflight")
-  , locker = require("../utils/locker.js")
-  , lock = locker.lock
-  , unlock = locker.unlock
   , addLocalTarball = require("./add-local-tarball.js")
   , cacheFile = require("npm-cache-filename")
 
@@ -26,9 +23,7 @@ function addRemoteTarball (u, pkgData, shasum, cb_) {
       data._shasum = data._shasum || shasum
       data._resolved = u
     }
-    unlock(u, function () {
-      cb_(er, data)
-    })
+    cb_(er, data)
   }
 
   cb_ = inflight(u, cb_)
@@ -44,25 +39,22 @@ function addRemoteTarball (u, pkgData, shasum, cb_) {
     addLocalTarball(tmp, pkgData, shasum, cb)
   }
 
-  lock(u, function (er) {
+  log.verbose("addRemoteTarball", [u, shasum])
+  mkdir(path.dirname(tmp), function (er) {
     if (er) return cb(er)
-
-    log.verbose("addRemoteTarball", [u, shasum])
-    mkdir(path.dirname(tmp), function (er) {
-      if (er) return cb(er)
-      addRemoteTarball_(u, tmp, shasum, next)
-    })
+    addRemoteTarball_(u, tmp, shasum, next)
   })
 }
 
 function addRemoteTarball_(u, tmp, shasum, cb) {
   // Tuned to spread 3 attempts over about a minute.
   // See formula at <https://github.com/tim-kos/node-retry>.
-  var operation = retry.operation
-    ( { retries: npm.config.get("fetch-retries")
-      , factor: npm.config.get("fetch-retry-factor")
-      , minTimeout: npm.config.get("fetch-retry-mintimeout")
-      , maxTimeout: npm.config.get("fetch-retry-maxtimeout") })
+  var operation = retry.operation({
+    retries: npm.config.get("fetch-retries")
+  , factor: npm.config.get("fetch-retry-factor")
+  , minTimeout: npm.config.get("fetch-retry-mintimeout")
+  , maxTimeout: npm.config.get("fetch-retry-maxtimeout")
+  })
 
   operation.attempt(function (currentAttempt) {
     log.info("retry", "fetch attempt " + currentAttempt
