@@ -85,6 +85,9 @@ var npm = require("./npm.js")
   , sortedObject = require("sorted-object")
   , mapToRegistry = require("./utils/map-to-registry.js")
   , npa = require("npm-package-arg")
+  , locker = require("./utils/locker.js")
+  , lock = locker.lock
+  , unlock = locker.unlock
 
 function install (args, cb_) {
   var hasArguments = !!args.length
@@ -206,7 +209,7 @@ function findPeerInvalid (where, cb) {
 
 function findPeerInvalid_ (packageMap, fpiList) {
   if (fpiList.indexOf(packageMap) !== -1)
-    return
+    return undefined
 
   fpiList.push(packageMap)
 
@@ -261,7 +264,13 @@ function readDependencies (context, where, opts, cb) {
     if (opts && opts.dev) {
       if (!data.dependencies) data.dependencies = {}
       Object.keys(data.devDependencies || {}).forEach(function (k) {
-        data.dependencies[k] = data.devDependencies[k]
+        if (data.dependencies[k]) {
+          log.warn("package.json", "Dependency '%s' exists in both dependencies " +
+                   "and devDependencies, using '%s@%s' from dependencies",
+                    k, k, data.dependencies[k])
+        } else {
+          data.dependencies[k] = data.devDependencies[k]
+        }
       })
     }
 
@@ -293,11 +302,9 @@ function readDependencies (context, where, opts, cb) {
     var wrapfile = path.resolve(where, "npm-shrinkwrap.json")
 
     fs.readFile(wrapfile, "utf8", function (er, wrapjson) {
-      if (er) {
-        log.verbose("readDependencies", "using package.json deps")
-        return cb(null, data, null)
-      }
+      if (er) return cb(null, data, null)
 
+      log.verbose("readDependencies", "npm-shrinkwrap.json is overriding dependencies")
       var newwrap
       try {
         newwrap = JSON.parse(wrapjson)
@@ -347,7 +354,7 @@ function save (where, installed, tree, pretty, hasArguments, cb) {
   }
 
   var saveBundle = npm.config.get("save-bundle")
-  var savePrefix = npm.config.get("save-prefix") || "^"
+  var savePrefix = npm.config.get("save-prefix")
 
   // each item in the tree is a top-level thing that should be saved
   // to the package.json file.
@@ -552,30 +559,58 @@ function installManyTop_ (what, where, context, cb) {
 
   fs.readdir(nm, function (er, pkgs) {
     if (er) return installMany(what, where, context, cb)
-    pkgs = pkgs.filter(function (p) {
+
+    var scopes = [], unscoped = []
+    pkgs.filter(function (p) {
       return !p.match(/^[\._-]/)
+    }).forEach(function (p) {
+      // @names deserve deeper investigation
+      if (p[0] === "@") {
+        scopes.push(p)
+      }
+      else {
+        unscoped.push(p)
+      }
     })
-    asyncMap(pkgs.map(function (p) {
-      return path.resolve(nm, p, "package.json")
-    }), function (jsonfile, cb) {
-      readJson(jsonfile, log.warn, function (er, data) {
-        if (er && er.code !== "ENOENT" && er.code !== "ENOTDIR") return cb(er)
-        if (er) return cb(null, [])
-        return cb(null, [[data.name, data.version]])
+
+    maybeScoped(scopes, nm, function (er, scoped) {
+      if (er && er.code !== "ENOENT" && er.code !== "ENOTDIR") return cb(er)
+      // recombine unscoped with @scope/package packages
+      asyncMap(unscoped.concat(scoped).map(function (p) {
+        return path.resolve(nm, p, "package.json")
+      }), function (jsonfile, cb) {
+        readJson(jsonfile, log.warn, function (er, data) {
+          if (er && er.code !== "ENOENT" && er.code !== "ENOTDIR") return cb(er)
+          if (er) return cb(null, [])
+          cb(null, [[data.name, data.version]])
+        })
+      }, function (er, packages) {
+        // if there's nothing in node_modules, then don't freak out.
+        if (er) packages = []
+        // add all the existing packages to the family list.
+        // however, do not add to the ancestors list.
+        packages.forEach(function (p) {
+          context.family[p[0]] = p[1]
+        })
+        installMany(what, where, context, cb)
       })
-    }, function (er, packages) {
-      // if there's nothing in node_modules, then don't freak out.
-      if (er) packages = []
-      // add all the existing packages to the family list.
-      // however, do not add to the ancestors list.
-      packages.forEach(function (p) {
-        context.family[p[0]] = p[1]
-      })
-      return installMany(what, where, context, cb)
     })
   })
 }
 
+function maybeScoped (scopes, where, cb) {
+  // find packages in scopes
+  asyncMap(scopes, function (scope, cb) {
+    fs.readdir(path.resolve(where, scope), function (er, scoped) {
+      if (er) return cb(er)
+      var paths = scoped.map(function (p) {
+        return path.join(scope, p)
+      })
+      cb(null, paths)
+    })
+  }, cb)
+}
+
 function installMany (what, where, context, cb) {
   // readDependencies takes care of figuring out whether the list of
   // dependencies we'll iterate below comes from an existing shrinkwrap from a
@@ -615,7 +650,7 @@ function installMany (what, where, context, cb) {
       targets.forEach(function (t) {
         newPrev[t.name] = t.version
       })
-      log.silly("resolved", targets)
+      log.silly("install resolved", targets)
       targets.filter(function (t) { return t }).forEach(function (t) {
         log.info("install", "%s into %s", t._id, where)
       })
@@ -653,9 +688,8 @@ function targetResolver (where, context, deps) {
       // don't even mess with non-package looking things
       inst = inst.filter(function (p) {
         if (!p.match(/^[@\._-]/)) return true
-        // scope pacakges
-        var scopepath = path.join(name, p)
-        readdir(scopepath)
+        // scoped packages
+        readdir(path.join(name, p))
       })
 
       asyncMap(inst, function (pkg, cb) {
@@ -856,7 +890,7 @@ function isIncompatibleInstallOneInProgress(target, where) {
          installOnesInProgress[target.name].indexOf(where) !== -1
 }
 
-function installOne_ (target, where, context, cb) {
+function installOne_ (target, where, context, cb_) {
   var nm = path.resolve(where, "node_modules")
     , targetFolder = path.resolve(nm, target.name)
     , prettyWhere = path.relative(process.cwd(), where)
@@ -867,34 +901,42 @@ function installOne_ (target, where, context, cb) {
   if (isIncompatibleInstallOneInProgress(target, where)) {
     // just call back, with no error.  the error will be detected in the
     // final check for peer-invalid dependencies
-    return cb()
+    return cb_()
   }
 
-  if (!(target.name in installOnesInProgress)) {
-    installOnesInProgress[target.name] = []
+  function cb(er, data) {
+    unlock(nm, target.name, function () { cb_(er, data) })
   }
-  installOnesInProgress[target.name].push(where)
-  var indexOfIOIP = installOnesInProgress[target.name].length - 1
-    , force = npm.config.get("force")
-    , nodeVersion = npm.config.get("node-version")
-    , strict = npm.config.get("engine-strict")
-    , c = npmInstallChecks
 
-  chain
-    ( [ [c.checkEngine, target, npm.version, nodeVersion, force, strict]
-      , [c.checkPlatform, target, force]
-      , [c.checkCycle, target, context.ancestors]
-      , [c.checkGit, targetFolder]
-      , [write, target, targetFolder, context] ]
-    , function (er, d) {
-        installOnesInProgress[target.name].splice(indexOfIOIP, 1)
+  lock(nm, target.name, function (er) {
+    if (er) return cb(er)
 
-        if (er) return cb(er)
+    if (!(target.name in installOnesInProgress)) {
+      installOnesInProgress[target.name] = []
+    }
+    installOnesInProgress[target.name].push(where)
+    var indexOfIOIP = installOnesInProgress[target.name].length - 1
+      , force = npm.config.get("force")
+      , nodeVersion = npm.config.get("node-version")
+      , strict = npm.config.get("engine-strict")
+      , c = npmInstallChecks
 
-        d.push(resultList(target, where, parent && parent._id))
-        cb(er, d)
-      }
-    )
+    chain(
+        [ [c.checkEngine, target, npm.version, nodeVersion, force, strict]
+        , [c.checkPlatform, target, force]
+        , [c.checkCycle, target, context.ancestors]
+        , [c.checkGit, targetFolder]
+        , [write, target, targetFolder, context] ]
+      , function (er, d) {
+          installOnesInProgress[target.name].splice(indexOfIOIP, 1)
+
+          if (er) return cb(er)
+
+          d.push(resultList(target, where, parent && parent._id))
+          cb(er, d)
+        }
+      )
+  })
 }
 
 function write (target, targetFolder, context, cb_) {
@@ -908,15 +950,15 @@ function write (target, targetFolder, context, cb_) {
     // is the list of installed packages from that last thing.
     if (!er) return cb_(er, data)
 
-    if (false === npm.config.get("rollback")) return cb_(er)
+    if (npm.config.get("rollback") === false) return cb_(er)
     npm.rollbacks.push(targetFolder)
     cb_(er, data)
   }
 
   var bundled = []
 
-  chain
-    ( [ [ cache.unpack, target.name, target.version, targetFolder
+  chain(
+      [ [ cache.unpack, target.name, target.version, targetFolder
         , null, null, user, group ]
       , [ fs, "writeFile"
         , path.resolve(targetFolder, "package.json")
