@@ -11,6 +11,7 @@ var url = require("url")
   , Conf = require("npmconf").Conf
   , RegClient = require("npm-registry-client")
   , mapToRegistry = require("./utils/map-to-registry.js")
+  , cachedPackageRoot = require("./cache/cached-package-root.js")
 
 publish.usage = "npm publish <tarball>"
               + "\nnpm publish <folder>"
@@ -55,10 +56,7 @@ function cacheAddPublish (dir, didPre, isRetry, cb) {
   npm.commands.cache.add(dir, null, null, false, function (er, data) {
     if (er) return cb(er)
     log.silly("publish", data)
-    var cachedir = path.resolve( npm.cache
-                               , data.name
-                               , data.version
-                               , "package" )
+    var cachedir = path.resolve(cachedPackageRoot(data), "package")
     chain([ !didPre &&
           [lifecycle, data, "prepublish", cachedir]
         , [publish_, dir, data, isRetry, cachedir]
